@@ -1,4 +1,6 @@
-"""Copyright (c) 2019, Douglas Otwell
+"""ble.connection.py
+
+Copyright (c) 2019, Douglas Otwell, DashIO
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -23,31 +25,36 @@ import logging
 import threading
 import time
 import uuid
+import shortuuid
 
 import dbus
 import dbus.exceptions
 import dbus.mainloop.glib
 import dbus.service
-import shortuuid
 import zmq
 from gi.repository import GLib
 
-from dashio.dashdevice import Device
+from dashio.device import Device
 
 from .constants import CONNECTION_PUB_URL, DEVICE_PUB_URL
 
 
 class BLE():
+    """BLE connection control
+    """
     def get_state(self) -> str:
+        """A CFG only control"""
         return ""
 
-    def get_cfg(self, num_columns):
-        cfg_str = "\tCFG\t" + self.msg_type + "\t" + json.dumps(self._cfg) + "\n"
+    def get_cfg(self, _) -> str:
+        """Called by iotdashboard app to get controls CFG
+        """
+        cfg_str = "\tCFG\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
     def __init__(self, control_id, service_uuid="", read_uuid="", write_uuid=""):
         self._cfg = {}
-        self.msg_type = "BLE"
+        self.cntrl_type = "BLE"
         self.control_id = control_id
         self.service_uuid = service_uuid
         self.read_uuid = read_uuid
@@ -55,6 +62,7 @@ class BLE():
 
     @property
     def service_uuid(self) -> str:
+        """ServiceUUID"""
         return self._cfg["serviceUUID"]
 
     @service_uuid.setter
@@ -63,6 +71,7 @@ class BLE():
 
     @property
     def read_uuid(self) -> str:
+        """readUUID"""
         return self._cfg["readUUID"]
 
     @read_uuid.setter
@@ -71,6 +80,7 @@ class BLE():
 
     @property
     def write_uuid(self) -> str:
+        """writeUUID"""
         return self._cfg["writeUUID"]
 
     @write_uuid.setter
@@ -89,35 +99,14 @@ GATT_MANAGER_IFACE = "org.bluez.GattManager1"
 GATT_SERVICE_IFACE = "org.bluez.GattService1"
 GATT_DESC_IFACE = "org.bluez.GattDescriptor1"
 
-class BleTools(object):
-    @classmethod
-    def get_bus(self):
-        bus = dbus.SystemBus()
-        return bus
-
-    @classmethod
-    def find_adapter(self, bus):
-        remote_om = dbus.Interface(bus.get_object(BLUEZ_SERVICE_NAME, "/"), DBUS_OM_IFACE)
-        objects = remote_om.GetManagedObjects()
-
-        for o, props in objects.items():
-            if LE_ADVERTISING_MANAGER_IFACE in props:
-                return o
-        return None
-
-    @classmethod
-    def power_adapter(self):
-        adapter = self.get_adapter()
-        adapter_props = dbus.Interface(bus.get_object(BLUEZ_SERVICE_NAME, adapter), "org.freedesktop.DBus.Properties")
-        adapter_props.Set("org.bluez.Adapter1", "Powered", dbus.Boolean(1))
-
 class DashIOAdvertisement(dbus.service.Object):
+    """BLE Advertisement
+    """
     PATH_BASE = "/org/bluez/example/advertisement"
 
     def __init__(self, index, service_uuid):
-        
         self.path = self.PATH_BASE + str(index)
-        self.bus = BleTools.get_bus()
+        self.bus = dbus.SystemBus()
         self.service_uuids = []
         self.service_uuids.append(service_uuid)
         self.properties = {}
@@ -128,61 +117,98 @@ class DashIOAdvertisement(dbus.service.Object):
         dbus.service.Object.__init__(self, self.bus, self.path)
         self.register()
 
+    def find_adapter(self, bus):
+        """Find BLE adapters"""
+        remote_om = dbus.Interface(bus.get_object(BLUEZ_SERVICE_NAME, "/"), DBUS_OM_IFACE)
+        objects = remote_om.GetManagedObjects()
+
+        for obj, props in objects.items():
+            if LE_ADVERTISING_MANAGER_IFACE in props:
+                return obj
+        return None
+
     def get_properties(self):
+        """Return the properties dictionary"""
         return {LE_ADVERTISEMENT_IFACE: self.properties}
 
     def get_path(self):
+        """Get the DBUS Path to BLE advertisement"""
         return dbus.ObjectPath(self.path)
 
+    # pylint: disable=invalid-name
     @dbus.service.method(DBUS_PROP_IFACE, in_signature="s", out_signature="a{sv}")
-    def GetAll(self, interface):
-        if interface != LE_ADVERTISEMENT_IFACE:
+    def GetAll(self, iface):
+        """DBUS calls this to retrieve Advertisements"""
+        if iface != LE_ADVERTISEMENT_IFACE:
             raise InvalidArgsException()
         return self.get_properties()[LE_ADVERTISEMENT_IFACE]
 
+    # pylint: disable=invalid-name
     @dbus.service.method(LE_ADVERTISEMENT_IFACE, in_signature='', out_signature='')
     def Release(self):
+        """DBUS calls this on release"""
         logging.debug('%s: Released!', self.path)
 
     def register_ad_callback(self):
+        """DBUS calls this on release"""
         logging.debug("GATT advertisement registered")
 
     def register_ad_error_callback(self):
+        """DBUS calls this on error"""
         logging.debug("Failed to register GATT advertisement")
 
     def register(self):
-        bus = BleTools.get_bus()
-        adapter = BleTools.find_adapter(bus)
+        """Register with DBUS"""
+        bus = self.bus
+        adapter = self.find_adapter(bus)
         ad_manager = dbus.Interface(bus.get_object(BLUEZ_SERVICE_NAME, adapter), LE_ADVERTISING_MANAGER_IFACE)
         ad_manager.RegisterAdvertisement(self.get_path(), {}, reply_handler=self.register_ad_callback, error_handler=self.register_ad_error_callback)
 
 
 class InvalidArgsException(dbus.exceptions.DBusException):
+    """DBUS errors"""
     _dbus_error_name = "org.freedesktop.DBus.Error.InvalidArgs"
 
 class NotSupportedException(dbus.exceptions.DBusException):
+    """DBUS errors"""
     _dbus_error_name = "org.bluez.Error.NotSupported"
 
 class NotPermittedException(dbus.exceptions.DBusException):
+    """DBUS errors"""
     _dbus_error_name = "org.bluez.Error.NotPermitted"
 
 class BLEConnection(dbus.service.Object, threading.Thread):
+    """BLEConnection
+    """
 
     def add_device(self, device: Device):
-        device.add_connection(self)
+        """Add a device to the connection
+
+        Parameters
+        ----------
+        device : Device
+            The device to add
+        """
+        device.rx_zmq_sub.connect(CONNECTION_PUB_URL.format(id=self.connection_id))
+        device.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, self.b_connection_id)
         device.add_control(self.ble_control)
         self.rx_zmq_sub.connect(DEVICE_PUB_URL.format(id=device.zmq_pub_id))
         self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, device.zmq_pub_id)
 
     def close(self):
-        self.quit()
+        """Close the connection
+        """
+        logging.debug("\nGATT application terminated")
+        self.tx_zmq_pub.close()
+        self.rx_zmq_sub.close()
+        self.mainloop.quit()
 
-    def zmq_callback(self, queue, condition):
+    def _zmq_callback(self, queue, condition):
         # logging.debug('zmq_callback')
 
         while self.rx_zmq_sub.getsockopt(zmq.EVENTS) & zmq.POLLIN:
             try:
-                [address, msg_id, data] = self.rx_zmq_sub.recv_multipart()
+                [_, _, data] = self.rx_zmq_sub.recv_multipart()
             except ValueError:
                 continue
             if not data:
@@ -191,26 +217,29 @@ class BLEConnection(dbus.service.Object, threading.Thread):
             # TODO: need to set this for the negitiated MTU
             # 160 seems to work with iPhone
             mtu = 160
-            date_lines = [data_str[i:i+mtu] for i in range(0, len(data_str), mtu)]
-            # delimiter = '\n'
-            # date_lines =  [e+delimiter for e in data_str.split(delimiter) if e]
-            # date_lines = data.decode('utf-8').split("\n")
-            logging.debug("BLE TX: %s", data_str.strip())
-            for data_line in date_lines:
-                self.dash_service.dash_characteristics.ble_send(data_line)
+            data_chunks = [data_str[i: i + mtu] for i in range(0, len(data_str), mtu)]
+
+            sent = False
+            for data_chunk in data_chunks:
+                sent |= self.dash_service.dash_characteristics.ble_send(data_chunk)
+            if sent:
+                logging.debug("BLE TX: %s", data_str.strip())
+
         return True
 
-    def ble_rx(self, msg: str):
+    def _ble_rx(self, msg: str):
         self.tx_zmq_pub.send_multipart([self.b_connection_id, b'1', msg.encode('utf-8')])
 
     def __init__(self, ble_uuid=None, context=None):
-        """
-        Arguments:
-        [Optional]
-            ble_uuid {str} -- The UUID used by BLE.
-            context {int} -- ZMQ context
-        """
+        """BLE Connection
 
+        Parameters
+        ----------
+        ble_uuid : str, optional
+            The UUID used by the BLE connection, if None a UUID is generated
+        context : ZMQ Context, optional
+            ZMQ Context, by default None
+        """
         threading.Thread.__init__(self, daemon=True)
 
         self.connection_id = shortuuid.uuid()
@@ -227,23 +256,21 @@ class BLEConnection(dbus.service.Object, threading.Thread):
         #     GLib.IO_IN | GLib.IO_ERR | GLib.IO_HUP | GLib.IO_PRI,
         #     self.zmq_callback
         # )
-        GLib.timeout_add(10, self.zmq_callback, "q", "p")
-        
+        GLib.timeout_add(10, self._zmq_callback, "q", "p")
         self.tx_zmq_pub = self.context.socket(zmq.PUB)
         self.tx_zmq_pub.bind(CONNECTION_PUB_URL.format(id=self.connection_id))
         dashio_service_uuid = ble_uuid or str(uuid.uuid4())
 
-        self.ble_control = BLE(self.connection_id, dashio_service_uuid, dashio_service_uuid, dashio_service_uuid)
+        self.ble_control = BLE(self.connection_id, dashio_service_uuid, str(uuid.uuid4()), str(uuid.uuid4()))
 
         GLib.threads_init()
         dbus.mainloop.glib.threads_init()
         dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
         self.mainloop = GLib.MainLoop()
 
-        self.bus = BleTools.get_bus()
+        self.bus = dbus.SystemBus()
         self.path = "/"
-        self.dash_service = DashIOService(0, dashio_service_uuid, self.ble_rx)
-        
+        self.dash_service = DashIOService(0, dashio_service_uuid, self._ble_rx)
         self.response = {}
 
         chrc = self.dash_service.get_characteristics()
@@ -251,44 +278,53 @@ class BLEConnection(dbus.service.Object, threading.Thread):
         self.response[self.dash_service.get_path()] = self.dash_service.get_properties()
 
         dbus.service.Object.__init__(self, self.bus, self.path)
-        self.register()
+        self._register()
         self.adv = DashIOAdvertisement(0, dashio_service_uuid)
         self.start()
         time.sleep(0.5)
 
+    def _find_adapter(self, bus):
+        remote_om = dbus.Interface(bus.get_object(BLUEZ_SERVICE_NAME, "/"), DBUS_OM_IFACE)
+        objects = remote_om.GetManagedObjects()
+
+        for obj, props in objects.items():
+            if LE_ADVERTISING_MANAGER_IFACE in props:
+                return obj
+        return None
+
     def get_path(self):
+        """Get DBUS path"""
         return dbus.ObjectPath(self.path)
 
+    # pylint: disable=invalid-name
     @dbus.service.method(DBUS_OM_IFACE, out_signature="a{oa{sa{sv}}}")
     def GetManagedObjects(self):
+        """Called by DBUS"""
         return self.response
 
-    def register_app_callback(self):
+    def _register_app_callback(self):
         logging.debug("GATT application registered")
 
-    def register_app_error_callback(self, error):
+    def _register_app_error_callback(self, error):
         logging.debug("Failed to register application: %s", str(error))
 
-    def register(self):
-        adapter = BleTools.find_adapter(self.bus)
+    def _register(self):
+        adapter = self._find_adapter(self.bus)
         service_manager = dbus.Interface(self.bus.get_object(BLUEZ_SERVICE_NAME, adapter), GATT_MANAGER_IFACE)
-        service_manager.RegisterApplication(self.get_path(), {}, reply_handler=self.register_app_callback, error_handler=self.register_app_error_callback)
+        service_manager.RegisterApplication(self._get_path(), {}, reply_handler=self._register_app_callback, error_handler=self._register_app_error_callback)
 
     def run(self):
         self.mainloop.run()
 
-    def quit(self):
-        logging.debug("\nGATT application terminated")
-        self.tx_zmq_pub.close()
-        self.rx_zmq_sub.close()
-        self.mainloop.quit()
 
 
 class DashIOService(dbus.service.Object):
+    """DBUS DashIO BLE service
+    """
     PATH_BASE = "/org/bluez/example/service"
 
     def __init__(self, index, service_uuid, ble_rx):
-        self.bus = BleTools.get_bus()
+        self.bus = dbus.SystemBus()
         self.path = self.PATH_BASE + str(index)
         self.uuid = service_uuid
         self.primary = True
@@ -298,6 +334,7 @@ class DashIOService(dbus.service.Object):
         dbus.service.Object.__init__(self, self.bus, self.path)
 
     def get_properties(self):
+        """Get DBUS properties"""
         return {
             GATT_SERVICE_IFACE: {
                 'UUID': self.uuid,
@@ -309,22 +346,28 @@ class DashIOService(dbus.service.Object):
         }
 
     def get_path(self):
+        """Get DBUS path"""
         return dbus.ObjectPath(self.path)
 
     def get_characteristic_paths(self):
+        """get DBUS properties"""
         result = []
         result.append(self.dash_characteristics.get_path())
         return result
 
     def get_characteristics(self):
+        """Get Dashio charactoristics"""
         return self.dash_characteristics
 
     def get_bus(self):
+        """Return the DBUS bus"""
         return self.bus
 
+    # pylint: disable=invalid-name
     @dbus.service.method(DBUS_PROP_IFACE, in_signature='s', out_signature='a{sv}')
-    def GetAll(self, interface):
-        if interface != GATT_SERVICE_IFACE:
+    def GetAll(self, iface):
+        """Called by DBUS"""
+        if iface != GATT_SERVICE_IFACE:
             raise InvalidArgsException()
         return self.get_properties()[GATT_SERVICE_IFACE]
 
@@ -344,6 +387,7 @@ class DashConCharacteristic(dbus.service.Object):
         dbus.service.Object.__init__(self, self.bus, self.path)
 
     def get_properties(self):
+        """Get DBUS properties"""
         return {
             GATT_CHRC_IFACE: {
                 'Service': self.service.get_path(),
@@ -353,45 +397,60 @@ class DashConCharacteristic(dbus.service.Object):
         }
 
     def get_path(self):
+        """Get DBUS path"""
         return dbus.ObjectPath(self.path)
 
+    # pylint: disable=invalid-name
     @dbus.service.method(DBUS_PROP_IFACE, in_signature='s', out_signature='a{sv}')
-    def GetAll(self, interface):
-        if interface != GATT_CHRC_IFACE:
+    def GetAll(self, iface):
+        """Called by DBUS"""
+        if iface != GATT_CHRC_IFACE:
             raise InvalidArgsException()
         return self.get_properties()[GATT_CHRC_IFACE]
 
+    # pylint: disable=invalid-name
     @dbus.service.method(GATT_CHRC_IFACE, in_signature='a{sv}', out_signature='ay')
-    def ReadValue(self, options):
+    def ReadValue(self, _):
+        """Called by DBUS"""
         logging.debug('Default ReadValue called, returning error')
         raise NotSupportedException()
 
+    # pylint: disable=invalid-name, unnecessary-pass
     @dbus.service.signal(DBUS_PROP_IFACE, signature='sa{sv}as')
     def PropertiesChanged(self, interface, changed, invalidated):
+        """Called by DBUS"""
         pass
 
     def get_bus(self):
+        """Return DBUS bus"""
         bus = self.bus
         return bus
 
     def ble_send(self, tx_data):
+        """Send data to BLE connection"""
         if self.notifying:
             value = [dbus.Byte(c.encode()) for c in tx_data]
             self.PropertiesChanged(GATT_CHRC_IFACE, {"Value": value}, [])
         return self.notifying
 
+    # pylint: disable=invalid-name
     @dbus.service.method(GATT_CHRC_IFACE)
     def StartNotify(self):
+        """Called by DBUS"""
         if self.notifying:
             return
         self.notifying = True
 
+    # pylint: disable=invalid-name
     @dbus.service.method(GATT_CHRC_IFACE)
     def StopNotify(self):
+        """Called by DBUS"""
         self.notifying = False
 
+    # pylint: disable=invalid-name
     @dbus.service.method(GATT_CHRC_IFACE, in_signature='aya{sv}')
     def WriteValue(self, value, options):
+        """Called by DBUS"""
         rx_str = ''.join([str(v) for v in value])
         self.read_buffer += rx_str
         if rx_str[-1] == '\n':
