@@ -1,9 +1,45 @@
+"""device_view.py
+
+Classes
+-------
+    DeviceView:
+        A DeviceView provides a control that descibes appearance and style of the group of controls
+        that are displayed on this DeviceView by the iotdashboard app.
+"""
 from .control import Control
 from .enums import Color, Icon
 
 
 class DeviceView(Control):
-    """A Config only control"""
+    """A DeviceView provides a control that descibes appearance and style of the group of controls
+        that are displayed on this DeviceView by the iotdashboard app.
+
+    Attributes
+    ----------
+    control_id : str
+       An unique control identity string. The control identity string must be a unique string for each control per device
+       Each control inherits the DeviceViews Control settings
+    title : str
+        The controls title
+    icon : Icon
+        The Icon representing the DeviceView
+    color : Color
+        The color of the DeviceView
+    share_column : Booloan
+        Something something
+    num_columns : int
+        Number of columns for DeviceView
+    control_title_box_color : Color
+        Title box color for controls
+    control_title_box_transparency : int
+        Title box transparency for controls
+
+
+    Methods
+    -------
+    add_control(Control) :
+        Add a control to the device view
+    """
 
     def __init__(
         self,
@@ -40,10 +76,24 @@ class DeviceView(Control):
         self._state_str = ""
 
     def add_control(self, control):
+        """Add a control to the DeviceView
+
+        Parameters
+        ----------
+        control : Control
+            The control to add
+        """
         control.parent_id = self.control_id
 
     @property
     def icon_name(self) -> Icon:
+        """Icon name
+
+        Returns
+        -------
+        Icon
+            Icon for the DeviceView
+        """
         return self._icon_name
 
     @icon_name.setter
@@ -53,6 +103,13 @@ class DeviceView(Control):
 
     @property
     def share_column(self) -> bool:
+        """[summary]
+
+        Returns
+        -------
+        bool
+            [description]
+        """
         return self._cfg["shareColumn"]
 
     @share_column.setter
@@ -61,6 +118,18 @@ class DeviceView(Control):
 
     @property
     def num_columns(self) -> int:
+        """[summary]
+
+        Returns
+        -------
+        int
+            Number of columns
+
+        Raises
+        ------
+        ValueError
+            The value must be 1 to 3
+        """
         return self._cfg["numColumns"]
 
     @num_columns.setter
@@ -72,6 +141,13 @@ class DeviceView(Control):
 
     @property
     def color(self) -> Color:
+        """Color
+
+        Returns
+        -------
+        Color
+            The device view color
+        """
         return self._color
 
     @color.setter
@@ -81,6 +157,13 @@ class DeviceView(Control):
 
     @property
     def control_title_box_color(self) -> Color:
+        """Control title box color
+
+        Returns
+        -------
+        Color
+            The control title box color
+        """
         return self._control_title_box_color
 
     @control_title_box_color.setter
@@ -90,6 +173,13 @@ class DeviceView(Control):
 
     @property
     def control_title_box_transparency(self) -> int:
+        """Control Box title transparency
+
+        Returns
+        -------
+        int
+            The percent transparency of the control box title
+        """
         return self._cfg["ctrlTitleBoxTransparency"]
 
     @control_title_box_transparency.setter
@@ -101,6 +191,13 @@ class DeviceView(Control):
 
     @property
     def control_color(self) -> Color:
+        """Controls color
+
+        Returns
+        -------
+        Color
+            The color of the control
+        """
         return self._control_color
 
     @control_color.setter
@@ -110,6 +207,13 @@ class DeviceView(Control):
 
     @property
     def control_border_color(self) -> Color:
+        """Control border color
+
+        Returns
+        -------
+        Color
+            The control border color
+        """
         return self._control_border_color
 
     @control_border_color.setter
@@ -119,6 +223,13 @@ class DeviceView(Control):
 
     @property
     def control_border_on(self) -> bool:
+        """Control border display
+
+        Returns
+        -------
+        bool
+            Set to true to display the contol borders
+        """
         return self._cfg["ctrlBorderOn"]
 
     @control_border_on.setter
@@ -127,6 +238,13 @@ class DeviceView(Control):
 
     @property
     def control_background_color(self) -> Color:
+        """Control background color
+
+        Returns
+        -------
+        Color
+            The control background color
+        """
         return self._control_background_color
 
     @control_background_color.setter
@@ -136,6 +254,13 @@ class DeviceView(Control):
 
     @property
     def control_title_font_size(self) -> int:
+        """Control title font size
+
+        Returns
+        -------
+        int
+            Control title font size
+        """
         return self._cfg["ctrlTitleFontSize"]
 
     @control_title_font_size.setter
@@ -144,6 +269,13 @@ class DeviceView(Control):
 
     @property
     def control_max_font_size(self) -> int:
+        """Control max font size
+
+        Returns
+        -------
+        int
+            Max font size for a control
+        """
         return self._cfg["ctrlMaxFontSize"]
 
     @control_max_font_size.setter
@@ -152,6 +284,13 @@ class DeviceView(Control):
 
     @property
     def control_background_transparency(self) -> int:
+        """Control background transparency
+
+        Returns
+        -------
+        int
+            the control background tranparency
+        """
         return self._cfg["ctrlBkgndTransparency"]
 
     @control_background_transparency.setter
