@@ -1,8 +1,17 @@
+"""graph.py
+
+Returns
+-------
+GraphLine
+    A line glass for a grapgh control.
+"""
+
 from .control import Control
 from .enums import Color, GraphLineType, GraphXAxisLabelsStyle, TitlePosition
 
-
 class GraphLine:
+    """GraphLine class
+    """
     def __init__(self, name="", line_type=GraphLineType.LINE, color=Color.BLACK):
         self.name = name
         self.line_type = line_type
@@ -10,6 +19,13 @@ class GraphLine:
         self.data = []
 
     def get_line_data(self):
+        """Returns the line data formated for the iotdashboard app
+
+        Returns
+        -------
+        str
+            The formatted line data
+        """
         data_str = f"\t{self.name}\t{self.line_type.value}\t{self.color.value}\t"
         data_str += "\t".join(map(str, self.data))
         data_str += "\n"
@@ -17,9 +33,17 @@ class GraphLine:
 
 
 class Graph(Control):
+    """A Graph control
+
+    Parameters
+    ----------
+    Control :
+        The control base class
+    """
     def get_state(self):
+        """Called by iotdashboard"""
         state_str = ""
-        for key in self.line_dict.keys():
+        for key in self.line_dict:
             state_str += self._control_hdr_str + key + self.line_dict[key].get_line_data()
         return state_str
 
@@ -52,17 +76,35 @@ class Graph(Control):
 
         self.line_dict = {}
 
-    def add_line(self, line_id, gline):
+    def add_line(self, line_id: str, gline: GraphLine):
+        """Add a line to the graph
+
+        Parameters
+        ----------
+        line_id : str
+            A unique to this graph line identifier
+        gline : GraphLine
+            The line to add
+        """
         self.line_dict[line_id] = gline
 
     def send_graph(self):
+        """Sends the graph to any connected iotdashboard app.
+        """
         state_str = ""
-        for key in self.line_dict.keys():
+        for key in self.line_dict:
             state_str += self._control_hdr_str + key + self.line_dict[key].get_line_data()
         self.state_str = state_str
 
     @property
     def x_axis_label(self) -> str:
+        """Returns the x_axis_label string.
+
+        Returns
+        -------
+        str
+            The x_axis_label
+        """
         return self._cfg["xAxisLabel"]
 
     @x_axis_label.setter
@@ -71,6 +113,13 @@ class Graph(Control):
 
     @property
     def x_axis_min(self) -> float:
+        """Returns the x_axis_min
+
+        Returns
+        -------
+        float
+            The x_axis_min
+        """
         return self._cfg["xAxisMin"]
 
     @x_axis_min.setter
@@ -79,6 +128,13 @@ class Graph(Control):
 
     @property
     def x_axis_max(self) -> float:
+        """Returns the x_axis_max
+
+        Returns
+        -------
+        float
+            The x_axis_max
+        """
         return self._cfg["xAxisMax"]
 
     @x_axis_max.setter
@@ -87,6 +143,13 @@ class Graph(Control):
 
     @property
     def x_axis_num_bars(self) -> int:
+        """Returns the x_axis_num_bars
+
+        Returns
+        -------
+        int
+            The x_axis_num_bars
+        """
         return self._cfg["xAxisNumBars"]
 
     @x_axis_num_bars.setter
@@ -95,6 +158,13 @@ class Graph(Control):
 
     @property
     def x_axis_labels_style(self) -> GraphXAxisLabelsStyle:
+        """Returns the x_axis_labels_style
+
+        Returns
+        -------
+        GraphXAxisLabelsStyle
+            The x_axis_labels_style
+        """
         return self._x_axis_labels_style
 
     @x_axis_labels_style.setter
@@ -104,6 +174,13 @@ class Graph(Control):
 
     @property
     def y_axis_label(self) -> str:
+        """Returns the y_axis_label
+
+        Returns
+        -------
+        str
+            The y_axis_label
+        """
         return self._cfg["yAxisLabel"]
 
     @y_axis_label.setter
@@ -112,6 +189,13 @@ class Graph(Control):
 
     @property
     def y_axis_min(self) -> float:
+        """Returns the y_axis_min
+
+        Returns
+        -------
+        float
+            The y_axis_min
+        """
         return self._cfg["yAxisMin"]
 
     @y_axis_min.setter
@@ -120,6 +204,13 @@ class Graph(Control):
 
     @property
     def y_axis_max(self) -> float:
+        """Returns the y_axis_max
+
+        Returns
+        -------
+        float
+            The y_axis_max
+        """
         return self._cfg["yAxisMax"]
 
     @y_axis_max.setter
@@ -128,6 +219,13 @@ class Graph(Control):
 
     @property
     def y_axis_num_bars(self) -> int:
+        """Returns the y_axis_num_bars
+
+        Returns
+        -------
+        int
+            The y_axis_num_bars
+        """
         return self._cfg["yAxisNumBars"]
 
     @y_axis_num_bars.setter
