@@ -1,8 +1,18 @@
+"""knobe.py
+
+Classes
+-------
+    Knob:
+        A class representing a Knob control
+"""
+
 from .control import Control
 from .enums import Color, KnobStyle, TitlePosition
 
 
 class Knob(Control):
+    """A Knob control
+    """
     def __init__(
         self,
         control_id,
@@ -19,6 +29,37 @@ class Knob(Control):
         knob_color=Color.RED,
         control_position=None,
     ):
+        """A Knob control is a control with a dial and knob.
+
+        Parameters
+        ----------
+        control_id : [type]
+            [description]
+        title : str, optional
+            [description], by default "A Knob"
+        title_position : [type], optional
+            [description], by default TitlePosition.BOTTOM
+        knob_style : [type], optional
+            [description], by default KnobStyle.NORMAL
+        dial_min : float, optional
+            [description], by default 0.0
+        dial_max : float, optional
+            [description], by default 100.0
+        red_value : float, optional
+            [description], by default 75.0
+        show_min_max : bool, optional
+            [description], by default False
+        send_only_on_release : bool, optional
+            [description], by default True
+        dial_follows_knob : bool, optional
+            [description], by default False
+        dial_color : [type], optional
+            [description], by default Color.BLUE
+        knob_color : [type], optional
+            [description], by default Color.RED
+        control_position : [type], optional
+            [description], by default None
+        """
         super().__init__("KNOB", control_id, title=title, control_position=control_position, title_position=title_position)
         self._control_id_dial = f"\t{{device_id}}\tKBDL\t{control_id}\t"
         self._knob_value = 0
@@ -41,6 +82,13 @@ class Knob(Control):
 
     @property
     def knob_value(self) -> float:
+        """knob value
+
+        Returns
+        -------
+        float
+            The value of the knob
+        """
         return self._knob_value
 
     @knob_value.setter
@@ -52,6 +100,13 @@ class Knob(Control):
 
     @property
     def knob_dial_value(self) -> float:
+        """Knob dial value
+
+        Returns
+        -------
+        float
+            The knob dial value
+        """
         return self._knob_dial_value
 
     @knob_dial_value.setter
@@ -63,6 +118,13 @@ class Knob(Control):
 
     @property
     def knob_style(self) -> KnobStyle:
+        """Knob style
+
+        Returns
+        -------
+        KnobStyle
+            The style of the knob
+        """
         return self._knob_style
 
     @knob_style.setter
@@ -72,6 +134,13 @@ class Knob(Control):
 
     @property
     def dial_min(self) -> float:
+        """Dial min
+
+        Returns
+        -------
+        float
+            The min value for the dial
+        """
         return self._cfg["min"]
 
     @dial_min.setter
@@ -80,6 +149,13 @@ class Knob(Control):
 
     @property
     def dial_max(self) -> float:
+        """Dial max
+
+        Returns
+        -------
+        float
+            The max value of the dial
+        """
         return self._cfg["max"]
 
     @dial_max.setter
@@ -88,6 +164,13 @@ class Knob(Control):
 
     @property
     def red_value(self) -> float:
+        """Knob red value
+
+        Returns
+        -------
+        float
+            The red value start from this value
+        """
         return self._cfg["redValue"]
 
     @red_value.setter
@@ -96,6 +179,13 @@ class Knob(Control):
 
     @property
     def show_min_max(self) -> bool:
+        """Show min max
+
+        Returns
+        -------
+        bool
+            True to show min/max
+        """
         return self._cfg["showMinMax"]
 
     @show_min_max.setter
@@ -104,6 +194,13 @@ class Knob(Control):
 
     @property
     def send_only_on_release(self) -> bool:
+        """Send only on release
+
+        Returns
+        -------
+        bool
+            True for iotdashboard to send updates only when control released
+        """
         return self._cfg["sendOnlyOnRelease"]
 
     @send_only_on_release.setter
@@ -112,6 +209,13 @@ class Knob(Control):
 
     @property
     def dial_follows_knob(self) -> bool:
+        """Dial follows knob
+
+        Returns
+        -------
+        bool
+            Set to true if the Dial follows the Knob
+        """
         return self._cfg["dialFollowsKnob"]
 
     @dial_follows_knob.setter
@@ -120,6 +224,13 @@ class Knob(Control):
 
     @property
     def dial_color(self) -> Color:
+        """The dial color
+
+        Returns
+        -------
+        Color
+            Color of the dial
+        """
         return self._dial_color
 
     @dial_color.setter
@@ -129,6 +240,13 @@ class Knob(Control):
 
     @property
     def knob_color(self) -> Color:
+        """Knob color
+
+        Returns
+        -------
+        Color
+            The color of the Knob
+        """
         return self._knob_color
 
     @knob_color.setter
