@@ -1,3 +1,4 @@
+"""tcpconnection.py"""
 import json
 import logging
 import socket
@@ -13,22 +14,46 @@ from .constants import CONNECTION_PUB_URL, DEVICE_PUB_URL
 
 
 class TCP():
+    """A CFG control class to store TCP connection information
+    """
+
     def get_state(self) -> str:
+        """Returns controls state. Not used for this control
+
+        Returns
+        -------
+        str
+            Not used in this control
+        """
         return ""
 
-    def get_cfg(self, _):
-        cfg_str = "\tCFG\t" + self.msg_type + "\t" + json.dumps(self._cfg) + "\n"
+    def get_cfg(self, _) -> str:
+        """Returns the CFG string for this TCP control
+
+        Returns
+        -------
+        str
+            The CFG string for this control
+        """
+        cfg_str = "\tCFG\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
     def __init__(self, control_id, ip_address="", port=5650):
         self._cfg = {}
-        self.msg_type = "TCP"
+        self.cntrl_type = "TCP"
         self.control_id = control_id
         self.ip_address = ip_address
         self.port = port
 
     @property
     def ip_address(self) -> str:
+        """IP address of current connection
+
+        Returns
+        -------
+        str
+            IP address
+        """
         return self._cfg["ipAddress"]
 
     @ip_address.setter
@@ -37,6 +62,13 @@ class TCP():
 
     @property
     def port(self) -> int:
+        """The port of the current connection
+
+        Returns
+        -------
+        int
+            The port number used by the current connection
+        """
         return self._cfg["port"]
 
     @port.setter
@@ -60,7 +92,15 @@ class TCPConnection(threading.Thread):
         self.zeroconf.register_service(zconf_info)
 
     def add_device(self, device):
-        device.add_connection(self)
+        """Add a device to the connection
+
+        Parameters
+        ----------
+        device : dashio.Device
+            Add a device to the connection.
+        """
+        device.rx_zmq_sub.connect(CONNECTION_PUB_URL.format(id=self.connection_id))
+        device.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, self.b_connection_id)
         device.add_control(self.tcp_control)
 
         self.rx_zmq_sub.connect(DEVICE_PUB_URL.format(id=device.zmq_pub_id))
@@ -72,7 +112,18 @@ class TCPConnection(threading.Thread):
             return port_s.connect_ex(('localhost', port)) == 0
 
     def __init__(self, ip_address="*", port=5650, use_zero_conf=True, context=None):
-        """
+        """TCP Connection
+
+        Parameters
+        ---------
+            ip_address : str, optional
+                IP Address to use. Defaults to "*".
+            port : int, optional
+                Port to use. Defaults to 5650.
+            use_zero_conf : bool, optional
+                Use mDNS to advertise the connection. Defaults to True.
+            context : optional
+                ZMQ context. Defaults to None.
         """
 
         threading.Thread.__init__(self, daemon=True)
@@ -81,7 +132,7 @@ class TCPConnection(threading.Thread):
         self.b_connection_id = self.connection_id.encode('utf-8')
         self.use_zeroconf = use_zero_conf
         while self._is_port_in_use(port) and use_zero_conf:
-            # increment port until we find one that is free. 
+            # increment port until we find one that is free.
             port += 1
         self.ext_url = "tcp://" + ip_address + ":" + str(port)
 
@@ -103,6 +154,8 @@ class TCPConnection(threading.Thread):
         time.sleep(1)
 
     def close(self):
+        """Close the connection."""
+
         if self.use_zeroconf:
             self.zeroconf.unregister_all_services()
             self.zeroconf.close()
