@@ -1,3 +1,5 @@
+
+"""zmqconnection.py"""
 import logging
 import socket
 import threading
@@ -7,10 +9,10 @@ import zmq
 from zeroconf import IPVersion, ServiceInfo, Zeroconf
 
 from . import ip
-
+from .constants import CONNECTION_PUB_URL
 
 class ZMQConnection(threading.Thread):
-    """Setups and manages a connection thread to iotdashboard via TCP."""
+    """Setups and manages a connection thread to iotdashboard via ZMQ."""
 
     def __zconf_publish_zmq(self, sub_port, pub_port):
         zconf_desc = {'sub_port': str(sub_port),
@@ -27,18 +29,37 @@ class ZMQConnection(threading.Thread):
         self.zeroconf.register_service(zconf_info)
 
     def add_device(self, device):
-        device.add_connection(self.connection_id)
+        """Add a device to the connection
+
+        Parameters
+        ----------
+        device : Device
+            The device to add to the connection
+        """
+        device.rx_zmq_sub.connect(CONNECTION_PUB_URL.format(id=self.connection_id))
+        device.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, self.b_connection_id)
         sub_topic = "\t{}".format(device.device_id)
         self.ext_rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, sub_topic.encode('utf-8'))
 
     def close(self):
+        """Close the connection."""
+
         self.zeroconf.unregister_all_services()
         self.zeroconf.close()
         self.running = False
 
     def __init__(self, zmq_out_url="*", pub_port=5555, sub_port=5556, context=None):
-        """
-        Arguments: figure it out for yourself.
+        """ZMQConnection
+
+        Parameters
+        ---------
+            zmq_out_url (str, optional):
+                URL to use. Defaults to "*".
+            pub_port (int, optional):
+                Port to publish with. Defaults to 5555.
+            sub_port (int, optional):
+                Port to subscribe with. Defaults to 5556.
+            context (ZMQ Context, optional): Defaults to None.
         """
 
         threading.Thread.__init__(self, daemon=True)
